From fe83cb12c2c275ccd922adc63d54b5b6c0604a2d Mon Sep 17 00:00:00 2001
Message-Id: <fe83cb12c2c275ccd922adc63d54b5b6c0604a2d.1348172464.git.wking@tremily.us>
From: "W. Trevor King" <wking@tremily.us>
Date: Thu, 20 Sep 2012 16:01:19 -0400
Subject: [PATCH] Add support for /Encoding/utf_8 to the FDF reader.

From PDF 32000-1:2008, section 12.7.7.3.1, table 243 (Entries in the
FDF dictionary), on page 459:

  Key: Encoding
  Type: name
  Value:

  (Optional; PDF 1.3) The encoding that shall be used for any FDF
  field value or option (V or Opt in the field dictionary; see Table
  246) or field name that is a string and does not begin with the
  Unicode prefix U+FEFF.

  Default value: PDFDocEncoding.

  Other allowed values include Shift_JIS, BigFive, GBK, UHC, utf_8,
  utf_16
---
 java/com/lowagie/text/pdf/FdfReader.java | 2 ++
 java/com/lowagie/text/pdf/PdfName.java   | 2 ++
 2 files changed, 4 insertions(+)

diff --git a/java/com/lowagie/text/pdf/FdfReader.java b/java/com/lowagie/text/pdf/FdfReader.java
index f8776ab..94b432e 100644
--- a/java/com/lowagie/text/pdf/FdfReader.java
+++ b/java/com/lowagie/text/pdf/FdfReader.java
@@ -188,6 +188,8 @@ public class FdfReader extends PdfReader {
                     return new String(b, "GBK");
                 else if (encoding.equals(PdfName.BIGFIVE))
                     return new String(b, "Big5");
+                else if (encoding.equals(PdfName.UTF_8))
+                    return new String(b, "UTF8");
             }
             catch (Exception e) {
             }
diff --git a/java/com/lowagie/text/pdf/PdfName.java b/java/com/lowagie/text/pdf/PdfName.java
index bd4aaeb..50d3704 100644
--- a/java/com/lowagie/text/pdf/PdfName.java
+++ b/java/com/lowagie/text/pdf/PdfName.java
@@ -903,6 +903,8 @@ public class PdfName extends PdfObject implements Comparable{
     /** A name */
     public static final PdfName USETHUMBS = new PdfName("UseThumbs");
     /** A name */
+    public static final PdfName UTF_8 = new PdfName("utf_8");
+    /** A name */
     public static final PdfName V = new PdfName("V");
     /** A name */
     public static final PdfName VERISIGN_PPKVS = new PdfName("VeriSign.PPKVS");
-- 
1.7.12.176.g3fc0e4c.dirty

